@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_codepipeline.paginator import (
     ListActionExecutionsPaginator,
@@ -73,41 +73,41 @@ __all__ = ("CodePipelineClient",)
 
 
 class Exceptions:
-    ActionNotFoundException: Boto3ClientError
-    ActionTypeNotFoundException: Boto3ClientError
-    ApprovalAlreadyCompletedException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ConcurrentModificationException: Boto3ClientError
-    DuplicatedStopRequestException: Boto3ClientError
-    InvalidActionDeclarationException: Boto3ClientError
-    InvalidApprovalTokenException: Boto3ClientError
-    InvalidArnException: Boto3ClientError
-    InvalidBlockerDeclarationException: Boto3ClientError
-    InvalidClientTokenException: Boto3ClientError
-    InvalidJobException: Boto3ClientError
-    InvalidJobStateException: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    InvalidNonceException: Boto3ClientError
-    InvalidStageDeclarationException: Boto3ClientError
-    InvalidStructureException: Boto3ClientError
-    InvalidTagsException: Boto3ClientError
-    InvalidWebhookAuthenticationParametersException: Boto3ClientError
-    InvalidWebhookFilterPatternException: Boto3ClientError
-    JobNotFoundException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    NotLatestPipelineExecutionException: Boto3ClientError
-    OutputVariablesSizeExceededException: Boto3ClientError
-    PipelineExecutionNotFoundException: Boto3ClientError
-    PipelineExecutionNotStoppableException: Boto3ClientError
-    PipelineNameInUseException: Boto3ClientError
-    PipelineNotFoundException: Boto3ClientError
-    PipelineVersionNotFoundException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    StageNotFoundException: Boto3ClientError
-    StageNotRetryableException: Boto3ClientError
-    TooManyTagsException: Boto3ClientError
-    ValidationException: Boto3ClientError
-    WebhookNotFoundException: Boto3ClientError
+    ActionNotFoundException: Type[Boto3ClientError]
+    ActionTypeNotFoundException: Type[Boto3ClientError]
+    ApprovalAlreadyCompletedException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ConcurrentModificationException: Type[Boto3ClientError]
+    DuplicatedStopRequestException: Type[Boto3ClientError]
+    InvalidActionDeclarationException: Type[Boto3ClientError]
+    InvalidApprovalTokenException: Type[Boto3ClientError]
+    InvalidArnException: Type[Boto3ClientError]
+    InvalidBlockerDeclarationException: Type[Boto3ClientError]
+    InvalidClientTokenException: Type[Boto3ClientError]
+    InvalidJobException: Type[Boto3ClientError]
+    InvalidJobStateException: Type[Boto3ClientError]
+    InvalidNextTokenException: Type[Boto3ClientError]
+    InvalidNonceException: Type[Boto3ClientError]
+    InvalidStageDeclarationException: Type[Boto3ClientError]
+    InvalidStructureException: Type[Boto3ClientError]
+    InvalidTagsException: Type[Boto3ClientError]
+    InvalidWebhookAuthenticationParametersException: Type[Boto3ClientError]
+    InvalidWebhookFilterPatternException: Type[Boto3ClientError]
+    JobNotFoundException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    NotLatestPipelineExecutionException: Type[Boto3ClientError]
+    OutputVariablesSizeExceededException: Type[Boto3ClientError]
+    PipelineExecutionNotFoundException: Type[Boto3ClientError]
+    PipelineExecutionNotStoppableException: Type[Boto3ClientError]
+    PipelineNameInUseException: Type[Boto3ClientError]
+    PipelineNotFoundException: Type[Boto3ClientError]
+    PipelineVersionNotFoundException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    StageNotFoundException: Type[Boto3ClientError]
+    StageNotRetryableException: Type[Boto3ClientError]
+    TooManyTagsException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
+    WebhookNotFoundException: Type[Boto3ClientError]
 
 
 class CodePipelineClient:
